@@ -23,7 +23,7 @@ from .globals import hvac_url, hvac_token, hvac_secret_id, hvac_role_id, hvac_co
     hvac_connections_mountpoint, hvac_token_env_var, hvac_secret_env_var, hvac_role_id_env_var
 
 
-def create_saspyconn(sasobjsp_host, sasobjsp_port, java=java):
+def create_saspyconn(sasobjsp_host, sasobjsp_port, appserver, java=java):
     saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=False)  # needed to manually deleted after, to be compitable with win
     saspy_conn.write(f"""SAS_config_names=['sasconnection']
 SAS_config_options = {{'lock_down': False,
@@ -34,6 +34,7 @@ SAS_output_options = {{'output' : 'html5'}}
 sasconnection = {{'java'      : '{java}',
             'iomhost'   : ['{sasobjsp_host}'],
             'iomport'   : {sasobjsp_port},
+            'appserver' : '{appserver}',
             'encoding': 'cyrillic',
             'options' : ["-fullstimer"]
             }}""")
@@ -47,6 +48,7 @@ class AbstractSAS(saspy.SASsession):
                        sasobjsp_pass,
                        sasobjsp_host,
                        sasobjsp_port,
+                       appserver,
                        java=java,
                        **kwargs):
         logging.debug('Initializing Abstract SAS class')
@@ -54,10 +56,12 @@ class AbstractSAS(saspy.SASsession):
         self.sasobjsp_port = sasobjsp_port
         self.sasobjsp_user = sasobjsp_user
         self.sasobjsp_pass = sasobjsp_pass
+        self.appserver = appserver
         self.java = java
         logging.debug('Generating saspy conn file')
         self.saspy_conn = create_saspyconn(sasobjsp_host=self.sasobjsp_host,
                                            sasobjsp_port=self.sasobjsp_port,
+                                           appserver=self.appserver,
                                            java=self.java)
         logging.debug(f'Generated saspy conn file {self.saspy_conn.name}')
         super(AbstractSAS, self).__init__(cfgfile=self.saspy_conn.name,
@@ -100,7 +104,6 @@ class AbstractSAS(saspy.SASsession):
         os.unlink(self.saspy_conn.name)  # need to do it manually for win systems
         super(AbstractSAS, self).endsas()
 
-
 def get_sas_connect(sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass, java=java):
     """
     LEGACY!!!!!
